#
#  engine
#
#  Playout Daemon for autoradio project
#
#
#  Copyright (C) 2017-2018 Gottfried Gaisbauer <gottfried.gaisbauer@servus.at>
#
#  This file is part of engine.
#
#  engine is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  any later version.
#
#  engine is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with engine. If not, see <http://www.gnu.org/licenses/>.
#

from sqlalchemy.ext.declarative import declarative_base
from flask_sqlalchemy import SQLAlchemy
# from flask_babel import Babel
from flask import Flask

from modules.base.config import ConfigReader # pylint: disable=import-error

def create_app(install_dir, uri):
    """
    creates flask app context
    :param install_dir: Installdir of Aura
    :param uri: Database connection uri
    :return: Flask object
    """
    app = Flask(__name__, template_folder=install_dir + '/modules/web/templates')
    app.config["SQLALCHEMY_DATABASE_URI"] = uri
    app.config['BABEL_DEFAULT_LOCALE'] = 'de'
    app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False

    return app

def create_database():
    """
    creates sqlalchemy database connection
    :return: SQLAlchemy object
    """
    #### load config ####
    config = ConfigReader()
    config.load_config()

    #### read config ####
    install_dir = config.get(str("install_dir"))
    db_name = config.get(str("db_name"))
    db_user = config.get(str("db_user"))
    db_pass = config.get(str("db_pass"))
    db_host = config.get(str("db_host"))

    #### create database conn ####
    uri = "mysql://"+db_user+":"+db_pass+"@"+db_host+"/"+db_name+"?charset=utf8"

    app = create_app(install_dir, uri)

    database = SQLAlchemy(app)
#    babel = Babel(app)

    return app, database


Base = declarative_base()
APP, DB = create_database()
