#
#  engine
#
#  Playout Daemon for autoradio project
#
#
#  Copyright (C) 2017-2018 Gottfried Gaisbauer <gottfried.gaisbauer@servus.at>
#
#  This file is part of engine.
#
#  engine is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  any later version.
#
#  engine is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with engine. If not, see <http://www.gnu.org/licenses/>.
#

from enum import Enum


class TerminalColors(Enum):
    HEADER = "\033[95m"

    RED = "\033[31m"
    GREEN = "\033[32m"
    ORANGE = "\033[33m"
    BLUE = "\033[34m"
    PINK = "\033[35m"
    CYAN = "\033[36m"

    WARNING = "\033[31m"
    FAIL = "\033[41m"

    BOLD = "\033[1m"
    UNDERLINE = "\033[4m"

    ENDC = "\033[0m"


class RedisChannel(Enum):
    STANDARD = "aura"

    DPE_REPLY = "delete_playlist_entry_reply"
    FNP_REPLY = "fetch_new_programme_reply"
    GAP_REPLY = "get_act_programme_reply"
    GCS_REPLY = "get_connection_status_reply"
    GNF_REPLY = "get_next_file_reply"
    IPE_REPLY = "insert_playlist_entry_reply"
    IP_REPLY  = "init_player_reply"
    MPE_REPLY = "move_playlist_entry_reply"
    PMQ_REPLY = "print_message_queue_reply"
    RDB_REPLY = "recreate_database_reply"
    SNF_REPLY = "get_next_file_reply"


class ScheduleEntryType(Enum):
    # enumeration with names of liquidsoap inputs
    FILESYSTEM = "input_fs"
    STREAM  = "input_http"
    LIVE_0 = "input_linein_0"
    LIVE_1 = "input_linein_1"
    LIVE_2 = "input_linein_2"
    LIVE_3 = "input_linein_3"
    LIVE_4 = "input_linein_4"


class LiquidSoapIDs(Enum):
    IN_LINEIN_0 = "input_linein_0"
    IN_LINEIN_1 = "input_linein_1"
    IN_LINEIN_2 = "input_linein_2"
    IN_LINEIN_3 = "input_linein_3"
    IN_LINEIN_4 = "input_linein_4"
    IN_STREAM = "input_stream"
    IN_FILE = "input_fs"

    OUT_LINEOUT_0 = "output_lineout_0"
    OUT_LINEOUT_1 = "output_lineout_1"
    OUT_LINEOUT_2 = "output_lineout_2"
    OUT_LINEOUT_3 = "output_lineout_3"
    OUT_LINEOUT_4 = "output_lineout_4"
    OUT_STREAM_0 = "output_stream_0"
    OUT_STREAM_1 = "output_stream_1"
    OUT_STREAM_2 = "output_stream_2"
    OUT_STREAM_3 = "output_stream_3"
    OUT_STREAM_4 = "output_stream_4"
    OUT_RECORDER_0 = "output_recorder_0"
    OUT_RECORDER_1 = "output_recorder_1"
    OUT_RECORDER_2 = "output_recorder_2"
    OUT_RECORDER_3 = "output_recorder_3"
    OUT_RECORDER_4 = "output_recorder_4"

    IN_MIXER = "input_mixer"


class LqsIDs():
    in_linein = [ LiquidSoapIDs.IN_LINEIN_0, LiquidSoapIDs.IN_LINEIN_1, LiquidSoapIDs.IN_LINEIN_2, LiquidSoapIDs.IN_LINEIN_3, LiquidSoapIDs.IN_LINEIN_4 ]
    in_stream = [ LiquidSoapIDs.IN_STREAM ]
    in_file = [ LiquidSoapIDs.IN_FILE ]
    out_lineout = [ LiquidSoapIDs.OUT_LINEOUT_0, LiquidSoapIDs.OUT_LINEOUT_1, LiquidSoapIDs.OUT_LINEOUT_2, LiquidSoapIDs.OUT_LINEOUT_3, LiquidSoapIDs.OUT_LINEOUT_4 ]
    out_streams = [ LiquidSoapIDs.OUT_STREAM_0, LiquidSoapIDs.OUT_STREAM_1, LiquidSoapIDs.OUT_STREAM_2, LiquidSoapIDs.OUT_STREAM_3, LiquidSoapIDs.OUT_STREAM_4 ]
    out_recorder = [ LiquidSoapIDs.OUT_RECORDER_0, LiquidSoapIDs.OUT_RECORDER_1, LiquidSoapIDs.OUT_RECORDER_2, LiquidSoapIDs.OUT_RECORDER_3, LiquidSoapIDs.OUT_RECORDER_4 ]


class FallbackType(Enum):
    SHOW = "show" # the first played when the show playlist fails
    STATION = "station" # the last played when everything else fails
    TIMESLOT = "timeslot" # the second played when show fallback fails


class TimerType(Enum):
    SWITCH = "switch"
    FADEIN = "fadein"
    FADEOUT = "fadeout"




